@@ -26,7 +26,7 @@ namespace Akonadi
 class ContactGroupEditorPrivate
 {
 public:
-    ContactGroupEditorPrivate(ContactGroupEditor *parent);
+    explicit ContactGroupEditorPrivate(ContactGroupEditor *parent);
     ~ContactGroupEditorPrivate();
 
     void itemFetchDone(KJob *job);
